@@ -4,7 +4,10 @@ from pathlib import Path
 from tempfile import TemporaryDirectory
 from typing import TYPE_CHECKING, Dict, List, Optional, Union
 
-from frogml_proto.qwak.build.v1.build_pb2 import DESCRIPTOR
+import requests
+from requests import Response
+from requests.auth import AuthBase
+
 from frogml_core.clients.analytics.client import AnalyticsEngineClient
 from frogml_core.clients.automation_management.client import AutomationsManagementClient
 from frogml_core.clients.batch_job_management.client import BatchJobManagerClient
@@ -45,6 +48,7 @@ from frogml_core.frogml_client.projects.project import Project
 from frogml_core.inner.build_config.build_config_v1 import BuildConfigV1
 from frogml_core.inner.tool.auth import FrogMLAuthClient
 from frogml_core.model.base import BaseModel
+from frogml_proto.qwak.build.v1.build_pb2 import DESCRIPTOR
 
 if TYPE_CHECKING:
     try:
@@ -888,3 +892,9 @@ class FrogMLClient:
             Task.from_proto(task)
             for task in model_execution_tasks_proto.batch_job.task_executions
         ]
+
+    @staticmethod
+    def download_artifact(download_url: str, timeout: int = 60) -> Response:
+        auth: AuthBase = FrogMLClient._get_auth_client().get_auth()
+
+        return requests.get(download_url, auth=auth, timeout=timeout)
