@@ -3,7 +3,7 @@ from typing import Any, Generator, List, Tuple
 
 import grpc
 import pytest
-
+from frogml_core.inner.di_configuration import FrogmlContainer
 from frogml_proto.jfml.model_version.v1.model_version_manager_service_pb2_grpc import (
     add_ModelVersionManagerServiceServicer_to_server,
 )
@@ -113,6 +113,9 @@ from frogml_proto.qwak.secret_service.secret_service_pb2_grpc import (
 from frogml_proto.qwak.self_service.user.v1.user_service_pb2_grpc import (
     add_UserServiceServicer_to_server,
 )
+from frogml_proto.qwak.service_discovery.service_discovery_location_service_pb2_grpc import (
+    add_LocationDiscoveryServiceServicer_to_server,
+)
 from frogml_proto.qwak.vectors.v1.collection.collection_service_pb2_grpc import (
     add_VectorCollectionServiceServicer_to_server,
 )
@@ -122,7 +125,6 @@ from frogml_proto.qwak.vectors.v1.vector_service_pb2_grpc import (
 from frogml_proto.qwak.workspace.workspace_service_pb2_grpc import (
     add_WorkspaceManagementServiceServicer_to_server,
 )
-from frogml_core.inner.di_configuration import FrogmlContainer
 from frogml_services_mock.mocks.alert_manager_service_api import (
     AlertManagerServiceApiMock,
 )
@@ -187,6 +189,9 @@ from frogml_services_mock.mocks.job_registry_service_api import (
 from frogml_services_mock.mocks.kube_captain_service_api import (
     KubeCaptainServiceApiMock,
 )
+from frogml_services_mock.mocks.location_discovery_service_api import (
+    LocationDiscoveryServiceApiMock,
+)
 from frogml_services_mock.mocks.logging_service import LoggingServiceApiMock
 from frogml_services_mock.mocks.model_management_service import (
     ModelsManagementServiceMock,
@@ -249,16 +254,17 @@ def frogml_container():
         feature_store,
         file_versioning,
         instance_template,
+        jfrog_gateway,
         kube_deployment_captain,
+        location_discovery,
         logging_client,
         model_management,
+        model_version_manager,
         project,
         secret_service,
         user_application_instance,
         vector_store,
         workspace_manager,
-        model_version_manager,
-        jfrog_gateway,
     )
     from frogml_core.clients.administration import (
         authentication,
@@ -303,6 +309,7 @@ def frogml_container():
             prompt_manager_client,
             model_version_manager,
             jfrog_gateway,
+            location_discovery,
         ]
     )
 
@@ -527,6 +534,11 @@ def attach_servicers(free_port, server):
                 RepositoryServiceMock,
                 add_RepositoryServiceServicer_to_server,
             ),
+            (
+                "location_discovery_service",
+                LocationDiscoveryServiceApiMock,
+                add_LocationDiscoveryServiceServicer_to_server,
+            ),
             ("port", free_port, None),
         ],
     )
